@@ -1,24 +1,9 @@
 /*
-    Copyright (C) 2017 by Kai Uwe Broulik <kde@privat.broulik.de>
-    Copyright (C) 2017 by David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2017 Kai Uwe Broulik <kde@privat.broulik.de>
+    SPDX-FileCopyrightText: 2017 David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
 
-    Permission is hereby granted, free of charge, to any person obtaining a copy
-    of this software and associated documentation files (the "Software"), to deal
-    in the Software without restriction, including without limitation the rights
-    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-    copies of the Software, and to permit persons to whom the Software is
-    furnished to do so, subject to the following conditions:
-
-    The above copyright notice and this permission notice shall be included in
-    all copies or substantial portions of the Software.
-
-    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-    THE SOFTWARE.
+    SPDX-License-Identifier: MIT
 */
 
 #include "settings.h"
@@ -48,7 +33,7 @@ const QMap<Settings::Environment, QString> Settings::environmentNames = {
     {Settings::Environment::Opera, QStringLiteral("opera")},
     {Settings::Environment::Vivaldi, QStringLiteral("vivaldi")},
     {Settings::Environment::Brave, QStringLiteral("brave")},
-    {Settings::Environment::Edge, QStringLiteral("edge")}
+    {Settings::Environment::Edge, QStringLiteral("edge")},
 };
 
 const QMap<Settings::Environment, EnvironmentDescription> Settings::environmentDescriptions = {
@@ -58,7 +43,7 @@ const QMap<Settings::Environment, EnvironmentDescription> Settings::environmentD
         QStringLiteral("google-chrome"),
         QStringLiteral("google.com"),
         QStringLiteral("Google"),
-        QStringLiteral("google-chrome")
+        QStringLiteral("google-chrome"),
     } },
     {Settings::Environment::Chromium, {
         QStringLiteral("chromium-browser"),
@@ -66,7 +51,7 @@ const QMap<Settings::Environment, EnvironmentDescription> Settings::environmentD
         QStringLiteral("chromium-browser"),
         QStringLiteral("google.com"),
         QStringLiteral("Google"),
-        QStringLiteral("chromium-browser")
+        QStringLiteral("chromium-browser"),
     } },
     {Settings::Environment::Firefox, {
         QStringLiteral("firefox"),
@@ -74,7 +59,7 @@ const QMap<Settings::Environment, EnvironmentDescription> Settings::environmentD
         QStringLiteral("firefox"),
         QStringLiteral("mozilla.org"),
         QStringLiteral("Mozilla"),
-        QStringLiteral("firefox")
+        QStringLiteral("firefox"),
     } },
     {Settings::Environment::Opera, {
         QStringLiteral("opera"),
@@ -82,7 +67,7 @@ const QMap<Settings::Environment, EnvironmentDescription> Settings::environmentD
         QStringLiteral("opera"),
         QStringLiteral("opera.com"),
         QStringLiteral("Opera"),
-        QStringLiteral("opera")
+        QStringLiteral("opera"),
     } },
     {Settings::Environment::Vivaldi, {
         QStringLiteral("vivaldi"),
@@ -91,7 +76,7 @@ const QMap<Settings::Environment, EnvironmentDescription> Settings::environmentD
         QStringLiteral("vivaldi-stable"),
         QStringLiteral("vivaldi.com"),
         QStringLiteral("Vivaldi"),
-        QStringLiteral("vivaldi")
+        QStringLiteral("vivaldi"),
     } },
     {Settings::Environment::Brave, {
         QStringLiteral("Brave"),
@@ -99,7 +84,7 @@ const QMap<Settings::Environment, EnvironmentDescription> Settings::environmentD
         QStringLiteral("brave-browser"),
         QStringLiteral("brave.com"),
         QStringLiteral("Brave"),
-        QStringLiteral("brave")
+        QStringLiteral("brave"),
     } },
     {Settings::Environment::Edge, {
         QStringLiteral("Edge"),
@@ -107,8 +92,8 @@ const QMap<Settings::Environment, EnvironmentDescription> Settings::environmentD
         QStringLiteral("microsoft-edge"),
         QStringLiteral("microsoft.com"),
         QStringLiteral("Microsoft"),
-        QStringLiteral("microsoft-edge")
-    } }
+        QStringLiteral("microsoft-edge"),
+    } },
 };
 
 Settings::Settings()
@@ -195,7 +180,7 @@ void Settings::handleData(const QString &event, const QJsonObject &data)
             PluginManager::self().settingsChanged(plugin, settingsObject);
         }
 
-        emit changed(data);
+        Q_EMIT changed(data);
     } else if (event == QLatin1String("openKRunnerSettings")) {
         QProcess::startDetached(QStringLiteral("systemsettings5"), {QStringLiteral("kcm_plasmasearch")});
     } else if (event == QLatin1String("setEnvironment")) {
@@ -239,6 +224,7 @@ bool Settings::setEnvironmentFromTasksModelIndex(const QModelIndex &idx)
     qApp->setDesktopFileName(service->desktopEntryName());
     qApp->setWindowIcon(QIcon::fromTheme(service->icon()));
 
+    m_tasksModel->disconnect(this); // prevent further signal emission to not deref a nullptr https://bugs.kde.org/show_bug.cgi?id=435811
     m_tasksModel->deleteLater();
     m_tasksModel = nullptr;
 
